subroutine fmtm(npts,dt,x,tbp,kspec,nf,freq,spec,err)

! 
! The program calls the mtspec subroutine to get the
! spectrum, as in Thomson (1982), and the 5 - 95% confidence
! intervals of the estimation using the jackknife approach. 
!
! Input
!	npts		number of points in time series
!	dt		sampling interval (in seconds)
!	x(npts)		the time series
!	tbp		the time-bandwidth product
!	kspec		number of tapers to use
!	nf		number of frequency points
!
! Output
!	freq(nf)	frequency bins (vector)
!	spec(nf)	the power spectrum
!	err(nf,2)	two vectors containing the 5 - 95% of the
!			spectrum estimation.
!
!	calls mtspec (mwlib.a library)
!

!**********************************************************************

   use spectra 

   implicit none

!  time series

   integer, intent(in) :: npts
   real(4), dimension(npts), intent(in) :: x
   
!  spectra and frequency

   integer, intent(in) :: nf

   real(4), dimension(nf), intent(out) :: spec, freq

   real(4), dimension(nf,2), intent(out) :: err

!  Spectral parameters

   integer, intent(in) :: kspec

   real(4), intent(in) :: tbp, dt
  
!********************************************************************

   if (npts <= 1) then
      write(6,'(a)') '>>> Too few terms in the series to estimate a spectrum'
      stop
   endif

      
   write(6,'(a,2i10)') 'Number of points in time series and fft ', npts, nf

!
!  Get the spectrum estimate
!

   call mtspec(npts,dt,x,tbp,kspec,nf,freq,spec,err=err)

end subroutine fmtm







