program jk_test

! 
! The program calls the mtspec subroutine to get the
! spectrum, as in Thomson (1982).  
!

!**********************************************************************

   use spectra 

   implicit none

!  time series

   integer :: npts
   real(8), dimension(:), allocatable :: x, t
   
!  spectra and frequency

   integer :: nf

   real(8), dimension(:), allocatable :: spec, freq, sbar, lambda

   complex(8), dimension(:, :), allocatable ::  yk 

   real(8), dimension(:,:), allocatable :: wt, sk, err

!  Spectral parameters

   integer :: kspec

   real(8) :: tbp, dt
  
!  Degrees of freedom

   real(8), dimension(:), allocatable ::  se



!  Others

   integer :: ios
   
   integer :: i, k

   character (len = 100) :: filename

!********************************************************************

   kspec = 8
   tbp   = 5.d0
   npts  = 361

   dt = 5.0d0 

   if (npts <= 1) then
      write(6,'(a)') '>>> Too few terms in the series to estimate a spectrum'
      stop
   endif

      
   nf = 1 + npts/2

   write(6,'(a,2i10)') 'Number of points in time series and fft ', npts, nf

!
!  Allocate memory
!

   allocate(x(npts))
   allocate(t(npts))
   allocate(freq(nf))
   allocate(spec(nf))
   allocate(err(nf,2))
   allocate(sbar(nf))
   allocate(yk(npts,kspec))
   allocate(sk(nf,kspec))
   allocate(wt(nf,kspec))
   allocate(se(nf))


!
!  Define time axis
!

   do i = 1,npts
      t(i) = dble(i)*dt
   enddo

   filename = 'th_data.dat'
   open (11, file=filename, status='old')

   do k = 1, npts
      read(11,*, iostat=ios) x(k)
      if (ios<0) then
         ! End of file encountered
         exit
      endif
   enddo

   close(11)

   print *, x(1:10)
!
!  Get the spectrum estimate
!

   call mtspec(npts,dt,x,tbp,kspec,nf,freq,spec,err=err,sbar=sbar,   &
                yk=yk, sk=sk, wt=wt, lambda=lambda)

!   call mtspec(npts,dt,x,tbp,kspec,nf,freq,spec,err=err)

   print *, spec(1:10)

   open(12,file='jk_spec.dat')
   write(6,'(4a16)') 'freq', 'spec', '-95%', '+95%'
   do i = 1,nf
      write(12,'(4E16.7)') freq(i), spec(i), err(i,1), err(i,2)
   enddo

   close(12)
   
end program jk_test

