program yk_back

!
!  Program to test how the going back from the yk's, to the
!  actual time series works. The signal recovered should be equal
!  to the initial signal.
!

!********************************************************************

   use spectra

   implicit none

!  time series

   integer :: npts

   real(8), dimension(:), allocatable    :: x, t
   real(8), dimension(:), allocatable :: xa, xb, xc
   real(4), dimension(:), allocatable :: xr

   complex(8), dimension(:), allocatable :: dummy_y

   complex(8), dimension(:), allocatable :: y

   real(8) :: fa, fb, fc

!  Spectral parameters

   integer :: kspec

   real(8) :: tbp, dt

!  spectra and frequency

   integer :: nf

   real(8), dimension(:), allocatable :: freq, spec

   real(8), dimension(:,:), allocatable :: vn

   complex(8), dimension(:,:), allocatable :: yk


!  Other

   integer :: i

   real(8), parameter :: pi = 3.14159265358979d0 

!********************************************************************

   kspec = 8
   tbp   = 5.d0
   npts = 601

   dt = 1.0d0 

   if (npts <= 1) then
      write(6,'(a)') '>>> Too few terms in the series to estimate a spectrum'
      stop
   endif

      
   nf = 1 + npts/2

   write(6,'(a,2i10)') 'Number of points in time series and fft ', npts, nf

!
!  Allocate memory
!

   allocate(x(npts))
   allocate(t(npts))
   allocate(y(npts))
   allocate(dummy_y(npts))
   allocate(xa(npts))
   allocate(xb(npts))
   allocate(xc(npts))
   allocate(xr(npts))
   allocate(freq(nf))

   allocate(spec(nf))
   allocate(yk(npts,kspec))
   allocate(vn(npts,kspec))


   t = dble( (/(i-1, i=1,npts)/) )

!   call set_random_seed

   fa = 0.d0
   fb = 0.075d0
   fc = 0.050d0

   call random_number(xr)

   xa = sin( 2.d0*pi*t*(fa + (fb-fa)*t/dble(600)) ) 
   x = xa + dble(xr)

   call mtspec( npts,dt,x,tbp,kspec,nf,                   &
                 freq,spec,yk=yk,vn=vn)

   dummy_y = yk(:,1)

   call ifft(dummy_y,npts)

   xb = real(dummy_y)

   xb = xb/(dble(npts)*vn(:,1))

   xb = xb - sum(xb)/dble(npts) + sum(x)/dble(npts)

!
!  Save data
!

   open(12,file='yk_ts.dat')
   write(6,'(3a16)') 'time', 'Signal', 'Signal2'
   do i = 1,npts
      write(12,'(3E16.7)') t(i), x(i), xb(i)
   enddo

   close(12)


   close(12)

   print *, 'Max abs error ', maxval(abs(x-xb))
   print *, 'Mean abs error ', sum(abs(x-xb))/dble(npts)

end program yk_back

subroutine set_random_seed

! Sets a random seed based on the system and wall clock time

!********************************************************************

   implicit none 

   integer , dimension(8)::val
   integer cnt
   integer sze
   integer, allocatable, dimension(:):: pt

!********************************************************************

   print *, sze
   call date_and_time(values=val)
   call system_clock(count=cnt)
   call random_seed(size=sze)

   print *, sze
   allocate(pt(sze))
   pt(1) = val(8)*val(3)
   pt(2) = cnt
   call random_seed(put=pt)
   deallocate(pt)

end subroutine set_random_seed


